## Changelog


### 0.2.0 - 2023-04-07

* Added Mage integration
* Updated README
* Fixed issues in RandomMapper
* Started the DimensionFiller class to fill conformed dimensions

### 0.1.3 - 2023-04-05

* Mild updates

### 0.1.2 - 2023-04-05

* Removed debugging outputs

### 0.1.1 - 2023-04-05

* First release
